@@ -14,6 +14,7 @@
 #ifndef _LG_DICT_COMMON_H_
 #define  _LG_DICT_COMMON_H_
 
+#include "api-types.h"
 #include "dict-structures.h"
 
 /* The functions here are for link-grammar internal use only.
@@ -24,6 +25,34 @@ bool find_word_in_dict(Dictionary dict, const char *);
 Exp * Exp_create(Dictionary);
 void add_empty_word(Dictionary, Dict_node *);
 
-void patch_subscript(char*);
+void patch_subscript(char *);
+
+/* Connector names for the affix class lists in the affix file */
+
+enum {
+	AFDICT_RPUNC=0,
+	AFDICT_LPUNC,
+	AFDICT_QUOTES,
+	AFDICT_UNITS,
+	AFDICT_SUF,
+	AFDICT_PRE,
+	AFDICT_MPRE,
+	AFDICT_SANEMORPHISM,
+	AFDICT_END /* must be last */
+} afdict_classnum;
+
+#define AFDICT_CLASSNAMES \
+	"RPUNC", \
+	"LPUNC", \
+	"QUOTES", \
+	"UNITS", \
+	"SUF",          /* SUF is used in the Russian dict */ \
+	"PRE",          /* PRE is not used anywhere, yet... */ \
+	"MPRE",         /* Multi-prefix, currently for Hebrew */ \
+	"SANEMORPHISM"  /* Regexp for sane_morphism() */
+
+#define AFCLASS(afdict, class) (&afdict->afdict_class[class])
+
+#define AFFIX_COUNT_MEM_INCREMENT 64
 
 #endif /* _LG_DICT_COMMON_H_ */
