@@ -4,8 +4,7 @@
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */ 
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */ 
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
@@ -25,6 +24,9 @@
 #ifndef _POSTPROCESS_H_
 #define _POSTPROCESS_H_
 
+#include "api-types.h"
+#include "structures.h"
+
 #define PP_FIRST_PASS  1
 #define PP_SECOND_PASS 2
 
